@@ -3,18 +3,19 @@ package Games::ABC_Path::Solver::Base;
 use warnings;
 use strict;
 
+use Games::ABC_Path::Solver::Constants;
+
 =head1 NAME
 
 Games::ABC_Path::Solver::Base - base class for Games::ABC_Path::Solver classes.
 
 =head1 VERSION
 
-Version 0.1.0
+Version 0.2.0
 
 =cut
 
-our $VERSION = '0.1.0';
-
+our $VERSION = '0.2.0';
 
 =head1 SYNOPSIS
 
@@ -44,6 +45,64 @@ sub new
     return $self;
 }
 
+use integer;
+
+sub _xy_to_int
+{
+    my ($self, $xy) = @_;
+
+=begin foo
+
+    {
+    my ($y, $x) = @{$xy}[$Y,$X];
+    if (($x < 0) or ($x > $LEN_LIM))
+    {
+        confess "X $x out of range.";
+    }
+
+    if (($y < 0) or ($y > $LEN_LIM))
+    {
+        confess "Y $y out of range.";
+    }
+    }
+=end foo
+
+=cut
+
+    return $xy->[$Y] * $LEN + $xy->[$X];
+}
+
+sub _to_xy
+{
+    my ($self, $int) = @_;
+
+    return (($int / $LEN), ($int % $LEN));
+}
+
+sub _y_indexes
+{
+    return (0 .. $LEN_LIM);
+}
+
+sub _x_indexes
+{
+    return (0 .. $LEN_LIM);
+}
+
+sub _x_in_range
+{
+    my ($self, $x) = @_;
+
+    return ($x >= 0 and $x < $LEN);
+}
+
+sub _y_in_range
+{
+    my ($self, $y) = @_;
+
+    return $self->_x_in_range($y);
+}
+
 =head1 AUTHOR
 
 Shlomi Fish, C<< <shlomif at cpan.org> >>
